@@ -87,7 +87,7 @@ def prompt(msg: str, default: Optional[str] = None) -> str:
 
 
 def find_files(
-    files: List[Union[str, Path]] = [], recursive: bool = True, files_to_exclude: List[Union[str, Path]] = [],
+    files: List[Union[str, Path]] = [], recursive: bool = True, files_to_exclude: List[Union[str, Path]] = []
 ) -> List[Path]:
     """Retrieve a list of all files belonging to supported extensions. The exploration can be made
     recursive and a list of files can be excluded if desired.
@@ -150,9 +150,7 @@ def persist_client_configuration(
 
     team_config = client.config.get_default_team()
     config = Config(config_path)
-    config.set_team(
-        team=team_config["slug"], api_key=team_config["api_key"], datasets_dir=team_config["datasets_dir"],
-    )
+    config.set_team(team=team_config["slug"], api_key=team_config["api_key"], datasets_dir=team_config["datasets_dir"])
     config.set_global(api_endpoint=client.url, base_url=client.base_url, default_team=default_team)
 
     return config
